---
title: '[릴리즈노트] 2024-03-25 업데이트'
category: 업데이트
tags:
  - 관리자콘솔
  - 업데이트
searchTags:
  - 업데이트
  - 릴리즈노트
datetime: 2024-04-16T07:11:17.699Z
---

<Callout title="2024년 3월 25일 관리자콘솔 업데이트 소식을 안내드립니다." />



### **주요 업데이트 사항**

✔️ 결제 연동 페이지가 새롭게 단장했습니다.

\[채널 관리]

- 기존 연동 관리와 달리 채널 추가 시 결제 모듈 별 지원되는 기능 및 결제 수단 정보를 쉽게 확인할 수 있습니다.
- 자세한 채널 추가 방법은 가이드를 참고해 주세요. [포트원 V1 채널 연동 가이드 보러가기 ↗](https://developers.portone.io/opi/ko/integration/ready/readme)

\[식별코드·API Keys]

- V2 API Secret을 발급할 수 있습니다.
- V2 API Secret의 경우 유효기간에 따라 갯수에 제한없이 발급이 가능합니다.

\[결제알림(Webhook) 관리]

- 포트원 V2 결제모듈에서 사용하는 웹훅 데이터 형식으로도 테스트할 수 있습니다.
- 포트원 V1/V2 결제 모듈 모두 테스트/실환경에 대해 웹훅을 각각 설정할 수 있습니다.

#### [\[관리자콘솔 릴리즈노트\] 2024-03-25 업데이트 보러가기↗](https://developers.portone.io/release-notes/console/2024-03-25?v=v1)
